@@ -190,9 +190,9 @@ class PhiConf:
                 popped_ws_data_from_path_map: Optional[
                     PhiWsData
                 ] = self._path_to_ws_data_map.pop(existing_ws_data.ws_root_path)
-                logger.debug(
-                    f"Pop {existing_ws_data.ws_root_path} from _path_to_ws_data_map"
-                )
+                # logger.debug(
+                #     f"Pop {existing_ws_data.ws_root_path} from _path_to_ws_data_map"
+                # )
             self._path_to_ws_data_map[_ws_data.ws_root_path] = self._ws_data_map[
                 ws_name
             ]
@@ -371,8 +371,10 @@ class PhiConf:
     def delete_ws(self, ws_name: str, delete_ws_dir: bool = False) -> bool:
         """Handles Deleting a workspace from the PhiConf"""
 
-        print_info(f"Deleting workspace: {ws_name}")
-        print_info(f"--> this does not delete any files, please delete them manually")
+        print_info(f"Deleting record for: {ws_name}")
+        print_info(
+            f"-*- Note: this does not delete any files on disk, please delete them manually"
+        )
 
         ws_data: Optional[PhiWsData] = self._ws_data_map.pop(ws_name, None)
         if ws_data is None:
