@@ -27,40 +27,46 @@ def deploy_docker_config(
     config: DockerConfig,
     name_filter: Optional[str] = None,
     type_filter: Optional[str] = None,
+    app_filter: Optional[str] = None,
     dry_run: Optional[bool] = False,
+    auto_confirm: Optional[bool] = False,
 ) -> bool:
 
     # Step 1: Get the DockerManager
     docker_manager: DockerManager = config.get_docker_manager()
     if docker_manager is None:
         raise DockerConfigException("DockerManager unavailable")
+    print_heading(f"--**-- Docker env: {config.env}\n")
 
     # Step 2: If dry_run, print the resources and return True
     if dry_run:
         docker_manager.create_resources_dry_run(
-            name_filter=name_filter, type_filter=type_filter
+            name_filter=name_filter,
+            type_filter=type_filter,
+            app_filter=app_filter,
+            auto_confirm=auto_confirm,
         )
         return True
 
     # Step 3: Create resources
-    env = config.env
-    print_subheading(
-        "Deploying docker config{}\n".format(
-            f" for env: {env}" if env is not None else ""
-        )
-    )
     try:
         success: bool = docker_manager.create_resources(
-            name_filter=name_filter, type_filter=type_filter
+            name_filter=name_filter,
+            type_filter=type_filter,
+            app_filter=app_filter,
+            auto_confirm=auto_confirm,
         )
         if not success:
             return False
-    except Exception:
-        raise
+    except Exception as e:
+        logger.error(e)
+        return False
 
     # Step 4: Validate resources are created
     resource_creation_valid: bool = docker_manager.validate_resources_are_created(
-        name_filter=name_filter, type_filter=type_filter
+        name_filter=name_filter,
+        type_filter=type_filter,
+        app_filter=app_filter,
     )
     if not resource_creation_valid:
         logger.error("DockerResource creation could not be validated")
@@ -74,46 +80,52 @@ def shutdown_docker_config(
     config: DockerConfig,
     name_filter: Optional[str] = None,
     type_filter: Optional[str] = None,
+    app_filter: Optional[str] = None,
     dry_run: Optional[bool] = False,
+    auto_confirm: Optional[bool] = False,
 ) -> bool:
 
     # Step 1: Get the DockerManager
     docker_manager: DockerManager = config.get_docker_manager()
     if docker_manager is None:
         raise DockerConfigException("DockerManager unavailable")
+    print_heading(f"--**-- Docker env: {config.env}\n")
 
     # Step 2: If dry_run, print the resources and return True
     if dry_run:
         docker_manager.delete_resources_dry_run(
-            name_filter=name_filter, type_filter=type_filter
+            name_filter=name_filter,
+            type_filter=type_filter,
+            app_filter=app_filter,
+            auto_confirm=auto_confirm,
         )
         return True
 
     # Step 3: Delete resources
-    env = config.env
-    print_subheading(
-        "Shutting down docker config{}\n".format(
-            f" for env: {env}" if env is not None else ""
-        )
-    )
     try:
         success: bool = docker_manager.delete_resources(
-            name_filter=name_filter, type_filter=type_filter
+            name_filter=name_filter,
+            type_filter=type_filter,
+            app_filter=app_filter,
+            auto_confirm=auto_confirm,
         )
         if not success:
             return False
-    except Exception:
-        raise
+    except Exception as e:
+        logger.error(e)
+        return False
 
     # Step 4: Validate resources are delete
     resources_deletion_valid: bool = docker_manager.validate_resources_are_deleted(
-        name_filter=name_filter, type_filter=type_filter
+        name_filter=name_filter,
+        type_filter=type_filter,
+        app_filter=app_filter,
     )
     if not resources_deletion_valid:
         logger.error("DockerResource deletion could not be validated")
         return False
 
-    print_info("Workspace shutdown")
+    print_info("Docker config shut down")
     return True
 
 
@@ -121,31 +133,34 @@ def patch_docker_config(
     config: DockerConfig,
     name_filter: Optional[str] = None,
     type_filter: Optional[str] = None,
+    app_filter: Optional[str] = None,
     dry_run: Optional[bool] = False,
+    auto_confirm: Optional[bool] = False,
 ) -> bool:
 
     # Step 1: Get the DockerManager
     docker_manager: DockerManager = config.get_docker_manager()
     if docker_manager is None:
         raise DockerConfigException("DockerManager unavailable")
+    print_heading(f"--**-- Docker env: {config.env}\n")
 
     # Step 2: If dry_run, print the resources and return True
     if dry_run:
         docker_manager.patch_resources_dry_run(
-            name_filter=name_filter, type_filter=type_filter
+            name_filter=name_filter,
+            type_filter=type_filter,
+            app_filter=app_filter,
+            auto_confirm=auto_confirm,
         )
         return True
 
     # Step 3: Patch resources
-    env = config.env
-    print_subheading(
-        "Patching docker config{}\n".format(
-            f" for env: {env}" if env is not None else ""
-        )
-    )
     try:
         success: bool = docker_manager.patch_resources(
-            name_filter=name_filter, type_filter=type_filter
+            name_filter=name_filter,
+            type_filter=type_filter,
+            app_filter=app_filter,
+            auto_confirm=auto_confirm,
         )
         if not success:
             return False
@@ -154,13 +169,15 @@ def patch_docker_config(
 
     # Step 4: Validate resources are patched
     resources_patch_valid: bool = docker_manager.validate_resources_are_deleted(
-        name_filter=name_filter, type_filter=type_filter
+        name_filter=name_filter,
+        type_filter=type_filter,
+        app_filter=app_filter,
     )
     if not resources_patch_valid:
         logger.error("DockerResource patch could not be validated")
         return False
 
-    print_info("Docker config patch")
+    print_info("Docker config patched")
     return True
 
 
