@@ -6,15 +6,20 @@ from phidata.infra.k8s.api_client import K8sApiClient
 from phidata.infra.k8s.config import K8sConfig
 from phidata.infra.k8s.exceptions import K8sConfigException
 from phidata.infra.k8s.manager import K8sManager
-from phidata.infra.k8s.resource.types import K8sResourceType
+from phidata.infra.k8s.resource.types import K8sResourceType, K8sResource
 from phidata.infra.k8s.resource.group import K8sResourceGroup
-from phidata.infra.k8s.resource.utils import filter_and_flatten_k8s_resource_groups
+from phidata.infra.k8s.resource.utils import (
+    get_k8s_resources_from_group,
+    filter_and_flatten_k8s_resource_groups,
+)
 from phidata.product import DataProduct
 from phidata.workflow import Workflow
 from phidata.types.context import PathContext, RunContext
+from phidata.utils.prep_infra_config import prep_infra_config
 
 from phiterm.workspace.phi_ws_data import PhiWsData
-from phiterm.workspace.ws_enums import WorkspaceEnv
+from phiterm.workspace.ws_enums import WorkspaceEnv, WorkspaceConfigType
+from phiterm.workspace.ws_operator import filter_and_prep_configs
 from phiterm.types.run_status import RunStatus
 from phiterm.utils.filesystem import delete_files_in_dir
 from phiterm.utils.cli_console import (
@@ -64,7 +69,7 @@ def deploy_k8s_config(
             return False
     except Exception as e:
         logger.error(e)
-        return False
+        raise
 
     # Step 4: Validate resources are created
     resource_creation_valid: bool = k8s_manager.validate_resources_are_created(
@@ -170,7 +175,7 @@ def patch_k8s_config(
             return False
     except Exception as e:
         logger.error(e)
-        return False
+        raise
 
     # Step 4: Validate resources are patched
     resources_patch_valid: bool = k8s_manager.validate_resources_are_patched(
@@ -188,9 +193,10 @@ def patch_k8s_config(
 
 def save_k8s_resources(
     ws_data: PhiWsData,
-    target_env: Optional[WorkspaceEnv] = None,
+    target_env: Optional[str] = None,
     target_name: Optional[str] = None,
     target_type: Optional[str] = None,
+    target_app: Optional[str] = None,
 ) -> None:
     """Saves the K8s resources"""
 
@@ -198,66 +204,28 @@ def save_k8s_resources(
         print_error("WorkspaceConfig invalid")
         return
     ws_config = ws_data.ws_config
+    # Set the local environment variables before processing configs
+    ws_config.set_local_env()
 
-    # Step 1: Get the K8sConfigs to build
-    configs_to_build: List[InfraConfig] = []
-    if target_env is None:
-        if ws_data.ws_config.k8s is not None:
-            configs_to_build.extend(ws_data.ws_config.k8s)
-    else:
-        for config in ws_data.ws_config.k8s:
-            if config.env is None:
-                continue
-            if config.env.lower() not in WorkspaceEnv.values_list():
-                print_error(f"{config.env} not supported")
-                continue
-            config_env = WorkspaceEnv.from_str(config.env)
-            if config_env == target_env:
-                configs_to_build.append(config)
+    configs_to_save: List[InfraConfig] = filter_and_prep_configs(
+        ws_config=ws_config,
+        target_env=target_env,
+        target_config=WorkspaceConfigType.k8s,
+        order="create",
+    )
+
+    num_configs_to_save = len(configs_to_save)
+    num_configs_saved = 0
+    for config in configs_to_save:
+        if not isinstance(config, K8sConfig):
+            continue
 
-    num_configs_to_build = len(configs_to_build)
-    num_configs_built = 0
-    for config in configs_to_build:
         env = config.env
         print_heading(
             "\nBuilding K8s manifests{}\n".format(
                 f" for env: {env}" if env is not None else ""
             )
         )
-        if not isinstance(config, InfraConfig):
-            print_error(f"{config} is not an instance of InfraConfig")
-            continue
-        if not isinstance(config, K8sConfig):
-            print_error(f"{config} is not an instance of K8sConfig")
-            continue
-        if not config.is_valid():
-            print_error("K8sConfig invalid")
-            continue
-        if not config.enabled:
-            logger.debug(
-                f"{config.__class__.__name__} for env {config.__class__.env} disabled"
-            )
-            num_configs_built += 1
-            continue
-
-        ######################################################################
-        # NOTE: VERY IMPORTANT TO GET RIGHT
-        # Update sub-configs data using WorkspaceConfig
-        # 1. Pass down the paths from the WorkspaceConfig
-        #       These paths are used everywhere from Infra to Apps
-        # 2. Pass down local_env, k8s_env, k8s_env for building PhidataApps
-        # 3. Pass down common cloud configuration. eg: aws_region, aws_profile
-        ######################################################################
-
-        # The ws_root_path is the ROOT directory for the workspace
-        config.workspace_root_path = ws_data.ws_root_path
-        config.workspace_config_file_path = ws_data.ws_config_file_path
-        config.scripts_dir = ws_config.scripts_dir
-        config.storage_dir = ws_config.storage_dir
-        config.meta_dir = ws_config.meta_dir
-        config.products_dir = ws_config.products_dir
-        config.notebooks_dir = ws_config.notebooks_dir
-        config.workspace_config_dir = ws_config.workspace_config_dir
 
         # Step 2: Get the K8sManager
         k8s_manager: K8sManager = config.get_k8s_manager()
@@ -283,7 +251,7 @@ def save_k8s_resources(
         # Step 4: Get the K8sResources
         k8s_resources: Optional[
             Dict[str, K8sResourceGroup]
-        ] = k8s_manager.get_resources()
+        ] = k8s_manager.get_resource_groups(app_filter=target_app)
         if k8s_resources is None or len(k8s_resources) == 0:
             print_error("No K8sResources to save")
             return
@@ -302,15 +270,16 @@ def save_k8s_resources(
             print_info(f"Processing {rg_name}")
             rg_dir: Path = resources_dir.joinpath(rg_name)
             rg_dir.mkdir(exist_ok=True)
-            resource_list: Optional[
-                List[K8sResourceType]
-            ] = filter_and_flatten_k8s_resource_groups(
-                k8s_resource_groups={rg_name: resource_group},
+
+            resource_list: List[K8sResource] = get_k8s_resources_from_group(
+                k8s_resource_group=resource_group,
                 name_filter=target_name,
                 type_filter=target_type,
             )
+
             if resource_list is None:
                 continue
+
             for resource in resource_list:
                 if resource is not None:
                     resource_name = resource.get_resource_name()
@@ -325,9 +294,9 @@ def save_k8s_resources(
                     except Exception as e:
                         logger.error(f"Could not parse {resource_name}")
                         continue
-        num_configs_built += 1
+        num_configs_saved += 1
 
-    print_info(f"\n# Configs built: {num_configs_built}/{num_configs_to_build}")
+    print_info(f"\n# Configs built: {num_configs_saved}/{num_configs_to_save}")
 
 
 def run_workflows_k8s(
