@@ -8,6 +8,8 @@ class WorkspaceVisibilityEnum(ExtendedEnum):
 
 class WorkspaceStarterTemplate(ExtendedEnum):
     aws = "aws"
+    aws_snowflake = "aws-snowflake"
+    aws_duckdb = "aws-duckdb"
 
 
 class WorkspaceEnv(ExtendedEnum):
