@@ -6,11 +6,7 @@ import git
 import typer
 
 from phidata.infra.base import InfraConfig
-from phidata.infra.docker.config import DockerConfig
-from phidata.infra.k8s.config import K8sConfig
-from phidata.infra.aws.config import AwsConfig
 from phidata.workspace import WorkspaceConfig
-from phidata.utils.prep_infra_config import prep_infra_config
 
 from phiterm.conf.constants import DEFAULT_WS_NAME
 from phiterm.conf.phi_conf import PhiConf, PhiWsData
@@ -20,31 +16,14 @@ from phiterm.utils.cli_console import (
     print_heading,
     print_info,
     print_subheading,
-    print_warning,
 )
-from phiterm.utils.common import is_empty, str_to_int
-from phiterm.utils.dttm import current_datetime_utc, dttm_to_dttm_str
-from phiterm.utils.filesystem import rmdir_recursive
-from phiterm.utils.git import GitCloneProgress, get_remote_origin_for_dir
 from phiterm.utils.log import logger
-from phiterm.workspace.template_to_repo_map import template_to_repo_map
 from phiterm.workspace.ws_enums import (
-    WorkspaceEnv,
     WorkspaceConfigType,
     WorkspaceStarterTemplate,
-    WorkspaceVisibilityEnum,
 )
 from phiterm.workspace.exceptions import WorkspaceConfigException
-from phiterm.workspace.ws_schemas import (
-    UpdateWorkspace,
-    UpsertWorkspaceFromCli,
-    WorkspaceSchema,
-)
-from phiterm.workspace.ws_utils import (
-    get_ws_config_file_path,
-    is_valid_ws_config_file_path,
-    print_howtofix_pending_actions,
-)
+from phiterm.workspace.ws_schemas import WorkspaceSchema
 
 # List of reserved workspace names
 RESERVED_WS_NAMES = ["root", "bedi", "ashpreet", "ashpreetbedi"]
@@ -65,6 +44,9 @@ def create_new_workspace(ws_name: str, template: WorkspaceStarterTemplate) -> bo
     NOTE: till the user runs `phi ws setup` the workspace is not registered with phidata
         and can only be used locally
     """
+    from phiterm.utils.filesystem import rmdir_recursive
+    from phiterm.workspace.template_to_repo_map import template_to_repo_map
+    from phiterm.workspace.ws_utils import get_ws_config_file_path
 
     current_dir: Path = Path(".").resolve()
 
@@ -149,6 +131,7 @@ def print_git_setup(
     ] = VersionControlProviderEnum.GITHUB,
 ) -> None:
     """Prints commands to setup a remote git repo for a workspace"""
+    from phiterm.utils.git import get_remote_origin_for_dir
 
     # Check if a remote origin is available
     _remote_origin_url: Optional[str] = get_remote_origin_for_dir(ws_root_path)
@@ -196,6 +179,8 @@ def clone_workspace(ws_to_clone: WorkspaceSchema, phi_conf: PhiConf) -> None:
     ws_root_path and ws_config_file_path in the ws_data. After updating the
     path, we're call setup_workspace() to go through our usual setup flow
     """
+    from phiterm.utils.git import GitCloneProgress
+    from phiterm.workspace.ws_utils import get_ws_config_file_path
 
     # Check if we can create the workspace in the current dir
     current_dir: Path = Path("../../workspace").resolve()
@@ -235,6 +220,7 @@ def create_workspace_using_input():
     """Takes input from the user and calls create_new_workspace()
     This function acts as an intermediary between initialize_workspace() and create_new_workspace()
     """
+    from phiterm.utils.common import is_empty, str_to_int
 
     # Get workspace name from user
     ws_name_inp_raw = input(f"Workspace name (default: {DEFAULT_WS_NAME}): ")
@@ -342,6 +328,12 @@ def setup_workspace(ws_root_path: Path) -> bool:
     `phi ws setup` is a generic catch-all function. It should handle errors graciously
     and provide "how to fix" messages and "next steps" to get the user running.
     """
+    from phiterm.utils.git import get_remote_origin_for_dir
+    from phiterm.workspace.ws_utils import (
+        get_ws_config_file_path,
+        is_valid_ws_config_file_path,
+        print_howtofix_pending_actions,
+    )
 
     print_heading("Running workspace setup\n")
 
@@ -537,6 +529,7 @@ def filter_and_prep_configs(
     target_config: Optional[WorkspaceConfigType] = None,
     order: Literal["create", "delete"] = "create",
 ) -> List[InfraConfig]:
+    from phidata.utils.prep_infra_config import prep_infra_config
 
     # Step 1. Filter configs
     # 1.1: Filter by config type: docker/k8s/aws
@@ -580,7 +573,7 @@ def filter_and_prep_configs(
                 continue
             if target_env == config.env:
                 configs_after_env_filter.append(config)
-    # logger.debug("Filtered configs: {}".format(configs_after_env_filter))
+    # logger.debug("Filtered configs: {}`".format(configs_after_env_filter))
 
     # Step 2. Prepare configs
     ready_to_use_configs: List[InfraConfig] = []
@@ -589,7 +582,7 @@ def filter_and_prep_configs(
             logger.error(f"{config} is not an instance of InfraConfig")
             continue
         if not config.is_valid():
-            logger.error("Config invalid")
+            logger.warning(f"Skipping {config.__class__}\n")
             continue
         if not config.enabled:
             logger.debug(
@@ -622,6 +615,9 @@ def deploy_workspace(
     auto_confirm: Optional[bool] = False,
 ) -> None:
     """Deploy a Phidata Workspace. This is called from `phi ws up`"""
+    from phidata.infra.docker.config import DockerConfig
+    from phidata.infra.k8s.config import K8sConfig
+    from phidata.infra.aws.config import AwsConfig
 
     if ws_data is None or ws_data.ws_config is None:
         logger.error("WorkspaceConfig invalid")
@@ -700,6 +696,9 @@ def shutdown_workspace(
     auto_confirm: Optional[bool] = False,
 ) -> None:
     """Shutdown the Phidata Workspace. This is called from `phi ws down`"""
+    from phidata.infra.docker.config import DockerConfig
+    from phidata.infra.k8s.config import K8sConfig
+    from phidata.infra.aws.config import AwsConfig
 
     if ws_data is None or ws_data.ws_config is None:
         logger.error("WorkspaceConfig invalid")
@@ -780,6 +779,9 @@ def patch_workspace(
     auto_confirm: Optional[bool] = False,
 ) -> None:
     """Patch the Phidata Workspace. This is called from `phi ws patch`"""
+    from phidata.infra.docker.config import DockerConfig
+    from phidata.infra.k8s.config import K8sConfig
+    from phidata.infra.aws.config import AwsConfig
 
     if ws_data is None or ws_data.ws_config is None:
         logger.error("WorkspaceConfig invalid")
